@@ -1,13 +1,16 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2022 -- leonerd@leonerd.org.uk
 
-use Object::Pad 0.52;  # ADJUSTPARAMS superclass bugfix
+use v5.20;
+use Object::Pad 0.70 ':experimental(adjust_params)';
 
-package Tickit::Widget 0.55;
+package Tickit::Widget 0.57;
 class Tickit::Widget :repr(HASH);
 
+use experimental 'postderef';
+
 use Carp;
 use Scalar::Util qw( blessed weaken );
 use List::Util 1.33 qw( all );
@@ -118,9 +121,9 @@ values.
 
 =cut
 
-has @_style_classes;
-has $_style_direct;
-has %_style_tag;
+field @_style_classes;
+field $_style_direct;
+field %_style_tag;
 
 ADJUST
 {
@@ -131,21 +134,26 @@ ADJUST
    }
 }
 
-ADJUSTPARAMS
-{
-   my ( $params ) = @_;
-
-   @_style_classes = @{ delete $params->{classes} // [ delete $params->{class} ] };
+ADJUST :params (
+   :$class = undef,
+   :$classes = [ $class ],
+) {
+   @_style_classes = $classes->@*;
+}
 
+ADJUST :params (
+   :$style = undef,
+   %params
+) {
    # Legacy direct-applied-style argument support
    foreach my $attr ( @Tickit::Pen::ALL_ATTRS ) {
-      next unless defined( my $val = delete $params->{$attr} );
+      next unless defined( my $val = delete $params{$attr} );
 
       carp "Applying legacy direct pen attribute '$attr' for ${\ref $self}";
-      $params->{style}{$attr} = $val;
+      $style->{$attr} = $val;
    }
 
-   if( my $style = delete $params->{style} ) {
+   if( $style ) {
       my $tagset = $_style_direct = Tickit::Style::_Tagset->new;
       foreach my $key ( keys %$style ) {
          $tagset->add( $key, $style->{$key} );
@@ -155,13 +163,13 @@ ADJUSTPARAMS
    $self->_update_pen( $self->get_style_pen );
 }
 
-has $_parent :reader;
-has $_window :reader;
-has $_pen    :reader;
+field $_parent :reader;
+field $_window :reader;
+field $_pen    :reader;
 
-has $_focus_pending;
+field $_focus_pending;
 
-has %_event_ids;
+field %_event_ids;
 
 =head1 METHODS
 
@@ -212,7 +220,7 @@ method set_style_tag
       KEYSET: foreach my $keyset ( $_style_direct->keysets ) {
          $keyset->tags->{$tag} or next KEYSET;
 
-         $values{$_} ||= [] for keys %{ $keyset->style };
+         $values{$_} ||= [] for keys $keyset->style->%*;
       }
    }
 
@@ -225,7 +233,7 @@ method set_style_tag
          KEYSET: foreach my $keyset ( $tagset->keysets ) {
             $keyset->tags->{$tag} or next KEYSET;
 
-            $keys{$_}++ for keys %{ $keyset->style };
+            $keys{$_}++ for keys $keyset->style->%*;
          }
 
          [ keys %keys ];
@@ -261,7 +269,7 @@ in scalar context.
 
 =cut
 
-has %_style_cache;
+field %_style_cache;
 
 method get_style_values
 {
@@ -290,7 +298,7 @@ method get_style_values
       defined $tagset or $tagset = Tickit::Style::_ref_tagset( $type, shift @classes );
 
       KEYSET: foreach my $keyset ( $tagset->keysets ) {
-         $_style_tag{$_} or next KEYSET for keys %{ $keyset->tags };
+         $_style_tag{$_} or next KEYSET for keys $keyset->tags->%*;
 
          my $style = $keyset->style;
 
@@ -334,7 +342,7 @@ returned pen instance is immutable, and may be cached.
 
 =cut
 
-has %_style_pen_cache;
+field %_style_pen_cache;
 
 method get_style_pen
 {
@@ -394,7 +402,7 @@ method set_style
 
    my %values;
    foreach my $keyset ( $new->keysets ) {
-      $values{$_} ||= [] for keys %{ $keyset->style };
+      $values{$_} ||= [] for keys $keyset->style->%*;
    }
 
    my @keys = keys %values;
@@ -686,8 +694,8 @@ window if the dimensions are now different to last time.
 
 =cut
 
-has $_req_lines;
-has $_req_cols;
+field $_req_lines;
+field $_req_cols;
 
 method set_requested_size
 {
